import 'dart:developer';

import 'package:hub/backend/schema/enums/enums.dart';
import 'package:hub/components/atomic_components/menu_button_item/menu_button_item_widget.dart';
import 'package:hub/components/atomic_components/menu_card_item/menu_card_item.dart';
import 'package:hub/components/molecular_components/menu_item/menu_item.dart';
import 'package:hub/flutter_flow/nav/nav.dart';

import '/components/organism_components/menu_list_view_component/menu_list_view_component_widget.dart';
import '/components/organism_components/menu_staggered_view_component/menu_staggered_view_component_widget.dart';
import '/flutter_flow/flutter_flow_util.dart';
import 'package:flutter/material.dart';
import 'menu_component_model.dart';
export 'menu_component_model.dart';

class MenuComponentWidget extends StatefulWidget {
  const MenuComponentWidget({
    Key? key,
    required this.style,
    required this.item,
    required this.expandable,
  });
  final MenuView style;
  final MenuItem item;
  final bool expandable;
  @override
  State<MenuComponentWidget> createState() => _MenuComponentWidgetState();
}

class _MenuComponentWidgetState extends State<MenuComponentWidget> {
  late MenuComponentModel _model;

  @override
  void setState(VoidCallback callback) {
    super.setState(callback);
    _model.onUpdate();
  }

  @override
  void initState() {
    super.initState();
    _model = createModel(context, () => MenuComponentModel());
  }

  @override
  void dispose() {
    _model.maybeDispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final options = widget.item == MenuItem.button
        ? <MenuEntry>[
            MenuButtonWidget(
              icon: FFIcons.kvector1,
              action: () async {
                await _model.scheduleVisitOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Schedule\nVisit',
                ptText: 'Agendar\nVisita',
              ),
            ),

            MenuButtonWidget(
              icon: FFIcons.khome,
              action: () async {
                await _model.registerVisitorOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Register\nVisitor',
                ptText: 'Cadastro\nde Visitante',
              ),
            ),

            // MenuButtonWidget(icon: FFIcons.kvector2, action: () async {setState(() {});}, title: FFLocalizations.of(context).getVariableText(enText:'Link\nCondominum' , ptText:'' ,),),
            // MenuButtonWidget(icon: FFIcons.kpets, action: () async {setState(() {});}, title: FFLocalizations.of(context).getVariableText(enText:'Register\Pet' , ptText:'' ,),),

            MenuButtonWidget(
              icon: Icons.qr_code,
              action: () async {
                await _model.accessQRCodeOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'QRCode\nAccess',
                ptText: 'QRCode\nde Acesso',
              ),
            ),

            MenuButtonWidget(
              icon: Icons.people,
              action: () async {
                await _model.peopleOnThePropertyAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Poeple on\nthe Property',
                ptText: 'Pessoas na\nPropriedade',
              ),
            ),

            MenuButtonWidget(
              icon: Icons.history_sharp,
              action: () async {
                await _model.liberationHistoryOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Consult\nHistories',
                ptText: 'Consultar\nHistóricos',
              ),
            ),

            MenuButtonWidget(
              icon: Icons.settings,
              action: () async {
                await _model.preferencesSettings(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Preferences\nSettings',
                ptText: 'Preferências \nde Configurações',
              ),
            ),
          ]
        : <MenuEntry>[
            MenuCardItem(
              icon: FFIcons.kvector1,
              action: () async {
                await _model.scheduleVisitOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Schedule\nVisit',
                ptText: 'Agendar\nVisita',
              ),
            ),

            MenuCardItem(
              icon: FFIcons.khome,
              action: () async {
                await _model.registerVisitorOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Register\nVisitor',
                ptText: 'Cadastro\nde Visitante',
              ),
            ),

            // MenuCardItem(icon: FFIcons.kvector2, action: () async {setState(() {});}, title: FFLocalizations.of(context).getVariableText(enText:'Link Condominum' , ptText:'' ,),),
            // MenuCardItem(icon: FFIcons.kpets, action: () async {setState(() {});}, title: FFLocalizations.of(context).getVariableText(enText:'Register\Pet' , ptText:'' ,),),

            MenuCardItem(
              icon: Icons.qr_code,
              action: () async {
                await _model.accessQRCodeOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'QRCode\nAccess',
                ptText: 'QRCode\nde Acesso',
              ),
            ),

            MenuCardItem(
              icon: Icons.people,
              action: () async {
                await _model.peopleOnThePropertyAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Poeple on\nthe Property',
                ptText: 'Pessoas\nna Propriedade',
              ),
            ),

            MenuCardItem(
              icon: Icons.history_sharp,
              action: () async {
                await _model.liberationHistoryOptAction(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Consult\nHistories',
                ptText: 'Consultar\nHistoricos',
              ),
            ),

            MenuCardItem(
              icon: Icons.settings,
              action: () async {
                await _model.preferencesSettings(context);
                setState(() {});
              },
              title: FFLocalizations.of(context).getVariableText(
                enText: 'Preferences\nSettings',
                ptText: 'Preferências\nde Configuração',
              ),
            ),
          ];
    return Padding(
      padding: const EdgeInsetsDirectional.fromSTEB(0.0, 10.0, 0.0, 0.0),
      child: Builder(
        builder: (context) {
          if (widget.style == MenuView.list_grid &&
              widget.expandable == true &&
              widget.item == MenuItem.button) {
            if (_model.isGrid == true) {
              return wrapWithModel(
                model: _model.menuListViewComponentModel,
                updateCallback: () => setState(() {}),
                updateOnChange: true,
                child: MenuListViewComponentWidget(
                  options: options,
                  expandable: widget.expandable,
                  item: widget.item,
                  changeMenuStyle: () async {
                    await _model.changeMenuStyle(context);
                    setState(() {});
                  },
                ),
              );
            } else {
              return wrapWithModel(
                model: _model.menuStaggeredViewComponentModel,
                updateCallback: () => setState(() {}),
                updateOnChange: true,
                child: MenuStaggeredViewComponentWidget(
                  options: options,
                  expandable: widget.expandable,
                  item: widget.item,
                  changeMenuStyle: () async {
                    await _model.changeMenuStyle(context);
                    setState(() {});
                  },
                ),
              );
            }
          }
          if (widget.style == MenuView.list &&
              widget.expandable == false &&
              widget.item == MenuItem.card) {
            return wrapWithModel(
              model: _model.menuListViewComponentModel,
              updateCallback: () => setState(() {}),
              updateOnChange: true,
              child: MenuListViewComponentWidget(
                options: options,
                expandable: widget.expandable,
                item: widget.item,
                changeMenuStyle: () async {
                  await _model.changeMenuStyle(context);
                  setState(() {});
                },
              ),
            );
          }
          return const SizedBox();
        },
      ),
    );
  }

  Future accessQRCodeOptAction(BuildContext context) async {
    context.pushNamed(
      'qrCodePage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }
}
